@@ -194,6 +194,26 @@ class NamedMatrix(object):
         maxdot.maxdot(A, B, C)
         return NamedMatrix(C, self.rownames, other.colnames)
     
+    def meandot(self, other):
+        """
+        Return the mean-dot product of self and other.
+        The mean of the regular dot product is taken where the denominator
+        is the number of non-zero elements.
+        """
+        if not self.colnames == other.rownames:
+            A = self[:, other.rownames]._data
+            B = other[self.colnames, :]._data
+        else:
+            A = self._data
+            B = other._data
+        
+        if not A.shape[1] == B.shape[0]:
+            raise Exception("Cannot multiply matrices shapes do not match: %s, %s" % (A.shape, B.shape))
+        
+        C = numpy.matrix(numpy.zeros((A.shape[0], B.shape[1])))
+        maxdot.meandot(A, B, C)
+        return NamedMatrix(C, self.rownames, other.colnames)
+    
     def remove_zero_rows(self):
         absmax = map(abs, self.max(1))
         keep = [i for i in range(self.size(0)) if not absmax[i] == 0]
